==> ngx_core-0.1.0.tar.gz: lib/src/services/application.dart <==
part of ngx_core;

/// Defines the methods and properties of the client application.
@Injectable()
class Application {

  /// The application settings.
  final Configuration _config;

  /// The current HTML document.
  final HtmlDocument _document;

  /// The service providing access to the meta tags.
  final Meta _meta;

  /// The service providing access to the browser's window.
  final Window _window;

  /// Creates a new configuration service.
  Application(@Inject(envToken) this.environment, this._config, @Inject(DOCUMENT) this._document, this._meta, this._window);

  /// Value indicating whether the application runs in debug mode.
  bool get debug => _config['debug'] ?? const ['development', 'test'].contains(environment);

  /// The application environment. Defaults to `"development"`.
  final String environment;

  /// Value indicating whether the application shoud use a secure connection.
  bool get forceSsl => _config['forceSsl'] ?? false;

  /// The language that the document is written in.
  String get language => _document.documentElement.lang;
  set language(String value) => _document.documentElement.lang = value;

  /// The application name. Defaults to `"My Application"`.
  String get name => _meta['application-name'] ?? 'My Application';
  set name(String value) => _meta['application-name'] = value;

  /// The base URL of the remote services.
  Uri get serviceUrl => _config['serviceUrl'] is String ? Uri.parse(_config['serviceUrl']) : null;

  /// The version number of the application package. Defaults to `"1.0"`.
  String get version => _config['version'] ?? const String.fromEnvironment('version', defaultValue: '1.0');

  /// Forces the currently requested URL to use a secure channel (e.g. HTTPS).
  void useSecureConnection() {
    var url = _window.location;
    if (url.protocol != 'https:') url.assign(url.href.replaceFirst(new RegExp(r'^[^:]+:'), 'https:'));
  }
}

==> ngx_core-0.2.0.tar.gz: lib/src/services/application.dart <==
part of ngx_core;

/// Defines the methods and properties of the client application.
@Injectable()
class Application {

  /// The application settings.
  final Configuration _config;

  /// The current HTML document.
  final dom.HtmlDocument _document;

  /// The service providing access to the meta tags.
  final Meta _meta;

  /// The browser's window.
  final dom.Window _window;

  /// Creates a new configuration service.
  Application(@Inject(envToken) this.environment, this._config, @Inject(DOCUMENT) this._document, this._meta, this._window);

  /// Value indicating whether the application runs in debug mode.
  bool get debug => _config['debug'] ?? const ['development', 'test'].contains(environment);

  /// The application environment. Defaults to `"development"`.
  final String environment;

  /// Value indicating whether the application shoud use a secure connection.
  bool get forceSsl => _config['forceSsl'] ?? false;

  /// The language that the document is written in.
  String get language => _document.documentElement.lang;
  set language(String value) => _document.documentElement.lang = value;

  /// The application name. Defaults to `"My Application"`.
  String get name => _meta['application-name'] ?? 'My Application';
  set name(String value) => _meta['application-name'] = value;

  /// The base URL of the remote services.
  Uri get serviceUrl => _config['serviceUrl'] is String ? Uri.parse(_config['serviceUrl']) : null;

  /// The version number of the application package. Defaults to `"1.0"`.
  String get version => _config['version'] ?? const String.fromEnvironment('version', defaultValue: '1.0');

  /// Forces the currently requested URL to use a secure channel (e.g. HTTPS).
  void useSecureConnection() {
    var url = _window.location;
    if (url.protocol != 'https:') url.assign(url.href.replaceFirst(new RegExp(r'^[^:]+:'), 'https:'));
  }
}
